@@ -11,6 +11,7 @@
 #include "sketch/gui_sketch_marker.h"
 #include "sketch/gui_sketch_action.h"
 #include "sketch/gui_sketch_style.h"
+#include "sketch/gui_sketch_texture.h"
 #include "gui_marked_set.h"
 #include "gui_resources.h"
 #include "gui_error.h"
@@ -74,6 +75,7 @@ struct gui_sketch_nav_tree_struct {
     gui_sketch_style_t sketch_style;
     gui_sketch_marker_t sketch_marker;
     gui_resources_t *resources;  /*!< pointer to external resources */
+    gui_sketch_texture_t *texture_downloader;  /*!< pointer to external gui_sketch_texture_t */
 };
 
 typedef struct gui_sketch_nav_tree_struct gui_sketch_nav_tree_t;
@@ -83,8 +85,12 @@ typedef struct gui_sketch_nav_tree_struct gui_sketch_nav_tree_t;
  *
  *  \param this_ pointer to own object attributes
  *  \param resources pointer to a graphics resource provider
+ *  \param texture_downloader pointer to a gui_sketch_texture_t that can draw a texture onto a cairo drawing context
  */
-void gui_sketch_nav_tree_init ( gui_sketch_nav_tree_t *this_, gui_resources_t *resources );
+void gui_sketch_nav_tree_init ( gui_sketch_nav_tree_t *this_,
+                                gui_resources_t *resources,
+                                gui_sketch_texture_t *texture_downloader
+                              );
 
 /*!
  *  \brief destroys the gui_sketch_nav_tree_t struct
