@@ -7,10 +7,6 @@
 #include <stdio.h>
 #include <stdbool.h>
 
-#if ( GTK_MAJOR_VERSION < 4 )
-#define gtk_widget_set_visible(w,v) ((v)?gtk_widget_show(w):gtk_widget_hide(w))
-#endif
-
 void gui_file_use_db_dialog_init ( gui_file_use_db_dialog_t *this_,
                                    ctrl_controller_t *controller,
                                    io_data_file_t *database,
@@ -19,6 +15,9 @@ void gui_file_use_db_dialog_init ( gui_file_use_db_dialog_t *this_,
 {
     U8_TRACE_BEGIN();
 
+    (*this_).parent_window = parent_window;
+
+#if (( GTK_MAJOR_VERSION == 4 )&&( GTK_MINOR_VERSION < 10 ))
     (*this_).use_db_file_chooser = gtk_file_chooser_dialog_new ( "Select DB to use",
                                                                  parent_window,
                                                                  GTK_FILE_CHOOSER_ACTION_SAVE,
@@ -29,19 +28,27 @@ void gui_file_use_db_dialog_init ( gui_file_use_db_dialog_t *this_,
                                                                  NULL
                                                                );
     /* set name postponed, see https://gitlab.gnome.org/GNOME/gtk/-/issues/4832 */
+#else
+    (*this_).use_db_file_dialog = gtk_file_dialog_new();
+    gtk_file_dialog_set_accept_label( (*this_).use_db_file_dialog, "Use DB-File" );
+    gtk_file_dialog_set_modal( (*this_).use_db_file_dialog, false );
+    gtk_file_dialog_set_title( (*this_).use_db_file_dialog, "Select DB to use" );
+    gtk_file_dialog_set_initial_name( (*this_).use_db_file_dialog, "NewModel.cfuJ" );
+#endif
 
     gui_file_db_manager_init( &((*this_).file_manager), controller, database, message_to_user );
 
+#if (( GTK_MAJOR_VERSION == 4 )&&( GTK_MINOR_VERSION < 10 ))
     g_signal_connect( G_OBJECT((*this_).use_db_file_chooser),
                       "response",
                       G_CALLBACK(gui_file_use_db_dialog_response_callback),
                       this_
                     );
-#if ( GTK_MAJOR_VERSION >= 4 )
     gtk_window_set_hide_on_close( GTK_WINDOW((*this_).use_db_file_chooser), true);
 #else
-    g_signal_connect( G_OBJECT((*this_).use_db_file_chooser), "delete-event", G_CALLBACK(gtk_widget_hide_on_delete), NULL );
+    /* no signal at new FileDialog - this works with Async, see gtk_file_dialog_save */
 #endif
+
     U8_TRACE_END();
 }
 
@@ -49,15 +56,17 @@ void gui_file_use_db_dialog_destroy( gui_file_use_db_dialog_t *this_ )
 {
     U8_TRACE_BEGIN();
 
-#if ( GTK_MAJOR_VERSION >= 4 )
+#if (( GTK_MAJOR_VERSION == 4 )&&( GTK_MINOR_VERSION < 10 ))
     gtk_window_destroy( GTK_WINDOW((*this_).use_db_file_chooser) );
-#else
-    gtk_widget_destroy( (*this_).use_db_file_chooser );
-#endif
     /* no need to g_object_unref ( (*this_).use_db_file_chooser ); here */
+#else
+    g_object_unref( (*this_).use_db_file_dialog );
+#endif
 
     gui_file_db_manager_destroy( &((*this_).file_manager) );
 
+    (*this_).parent_window = NULL;
+
     U8_TRACE_END();
 }
 
@@ -65,6 +74,7 @@ void gui_file_use_db_dialog_show( gui_file_use_db_dialog_t *this_, bool open_exi
 {
     U8_TRACE_BEGIN();
 
+#if (( GTK_MAJOR_VERSION == 4 )&&( GTK_MINOR_VERSION < 10 ))
     gtk_file_chooser_set_action( GTK_FILE_CHOOSER( (*this_).use_db_file_chooser ),
                                  open_existing ? GTK_FILE_CHOOSER_ACTION_OPEN : GTK_FILE_CHOOSER_ACTION_SAVE
                                );
@@ -74,7 +84,6 @@ void gui_file_use_db_dialog_show( gui_file_use_db_dialog_t *this_, bool open_exi
         gtk_file_chooser_set_current_name( GTK_FILE_CHOOSER( (*this_).use_db_file_chooser ), "untitled.cfuJ" );
     }
 
-#if ( GTK_MAJOR_VERSION >= 4 )
     gtk_widget_set_visible( GTK_WIDGET( (*this_).use_db_file_chooser ), TRUE );
 
     gtk_widget_set_sensitive( GTK_WIDGET((*this_).use_db_file_chooser), TRUE );  /* idea taken from gtk demo */
@@ -82,12 +91,31 @@ void gui_file_use_db_dialog_show( gui_file_use_db_dialog_t *this_, bool open_exi
     GdkSurface *surface = gtk_native_get_surface( GTK_NATIVE((*this_).use_db_file_chooser) );
     gdk_surface_set_cursor( surface, NULL );  /* idea taken from gtk3->4 guide */
 #else
-    gtk_widget_show_all( GTK_WIDGET( (*this_).use_db_file_chooser ) );
+    if ( open_existing )
+    {
+        gtk_file_dialog_open( (*this_).use_db_file_dialog,
+                              (*this_).parent_window,
+                              NULL,
+                              &gui_file_use_db_dialog_async_ready_callback_on_open,
+                              this_
+                            );
+    }
+    else
+    {
+        gtk_file_dialog_save( (*this_).use_db_file_dialog,
+                              (*this_).parent_window,
+                              NULL,
+                              &gui_file_use_db_dialog_async_ready_callback_on_save,
+                              this_
+                            );
+    }
 #endif
 
     U8_TRACE_END();
 }
 
+#if (( GTK_MAJOR_VERSION == 4 )&&( GTK_MINOR_VERSION < 10 ))
+
 void gui_file_use_db_dialog_response_callback( GtkDialog *dialog, gint response_id, gpointer user_data )
 {
     U8_TRACE_BEGIN();
@@ -101,15 +129,11 @@ void gui_file_use_db_dialog_response_callback( GtkDialog *dialog, gint response_
             gtk_widget_set_visible( GTK_WIDGET ( dialog ), FALSE );
 
             gchar *filename = NULL;
-#if ( GTK_MAJOR_VERSION >= 4 )
             GFile *selected_file = gtk_file_chooser_get_file( GTK_FILE_CHOOSER(dialog) );
             if ( selected_file != NULL )
             {
                 filename = g_file_get_path( selected_file );
             }
-#else
-            filename = gtk_file_chooser_get_filename( GTK_FILE_CHOOSER(dialog) );
-#endif
             if ( filename != NULL )
             {
                 U8_TRACE_INFO_STR( "File chosen:", filename );
@@ -122,12 +146,10 @@ void gui_file_use_db_dialog_response_callback( GtkDialog *dialog, gint response_
             {
                 U8_LOG_WARNING( "Use DB dialog returned no file name" );
             }
-#if ( GTK_MAJOR_VERSION >= 4 )
             if ( selected_file != NULL )
             {
                 g_object_unref( selected_file );
             }
-#endif
         }
         break;
 
@@ -153,6 +175,90 @@ void gui_file_use_db_dialog_response_callback( GtkDialog *dialog, gint response_
     U8_TRACE_END();
 }
 
+#else  /* GTK >= 4.10 */
+
+void gui_file_use_db_dialog_async_ready_callback_on_open( GObject* source_object,
+                                                          GAsyncResult* res,
+                                                          gpointer user_data )
+{
+    U8_TRACE_BEGIN();
+
+    gui_file_use_db_dialog_t *this_ = user_data;
+    GError* error = NULL;
+    GFile *result = gtk_file_dialog_open_finish( GTK_FILE_DIALOG(source_object), res, &error );
+    if ( error != NULL )
+    {
+        /* User pressed cancel */
+        U8_TRACE_INFO_STR( "unexpected response from file dialog:", error->message );
+        g_error_free( error );
+    }
+    if ( result != NULL )
+    {
+        gchar *folder_path = g_file_get_path ( result );
+        if ( folder_path != NULL )
+        {
+            U8_LOG_EVENT( "User selected a database file to open." );
+            U8_TRACE_INFO_STR( "File to open:", folder_path );
+
+            /* react immediately, handle events */
+            bool events_handled = true;
+            for ( uint_fast8_t max_loop = 40; events_handled && ( max_loop > 0 ); max_loop-- )
+            {
+                events_handled = g_main_context_iteration( NULL, /*may_block*/ FALSE );
+            }
+
+            gui_file_db_manager_use_db( &((*this_).file_manager), folder_path );
+
+            g_free (folder_path);
+        }
+        g_object_unref( result );
+    }
+
+    U8_TRACE_END();
+}
+
+void gui_file_use_db_dialog_async_ready_callback_on_save( GObject* source_object,
+                                                          GAsyncResult* res,
+                                                          gpointer user_data )
+{
+    U8_TRACE_BEGIN();
+
+    gui_file_use_db_dialog_t *this_ = user_data;
+    GError* error = NULL;
+    GFile *result = gtk_file_dialog_save_finish( GTK_FILE_DIALOG(source_object), res, &error );
+    if ( error != NULL )
+    {
+        /* User pressed cancel */
+        U8_TRACE_INFO_STR( "unexpected response from file dialog:", error->message );
+        g_error_free( error );
+    }
+    if ( result != NULL )
+    {
+        gchar *folder_path = g_file_get_path ( result );
+        if ( folder_path != NULL )
+        {
+            U8_LOG_EVENT( "User selected a new database file." );
+            U8_TRACE_INFO_STR( "File to create:", folder_path );
+
+            /* react immediately, handle events */
+            bool events_handled = true;
+            for ( uint_fast8_t max_loop = 40; events_handled && ( max_loop > 0 ); max_loop-- )
+            {
+                events_handled = g_main_context_iteration( NULL, /*may_block*/ FALSE );
+            }
+
+            gui_file_db_manager_use_db( &((*this_).file_manager), folder_path );
+
+            g_free (folder_path);
+        }
+        g_object_unref( result );
+    }
+
+    U8_TRACE_END();
+}
+
+#endif
+
 
 /*
 Copyright 2019-2024 Andreas Warnke
