@@ -39,7 +39,6 @@
 #include "integration/io_export_model_traversal_test.h"
 /* u8stream */
 #include "unit/u8__test.h"
-#include "unit/u8dir__test.h"
 #include "unit/universal_array_index_sorter_test.h"
 #include "unit/universal_array_list_test.h"
 #include "unit/universal_memory_output_stream_test.h"
@@ -58,6 +57,10 @@
 #include "unit/utf8stringviewiterator_test.h"
 #include "unit/utf8stringviewtokenizer_test.h"
 #include "unit/utf8stream_writer_test.h"
+#include "integration/u8dir_file_test.h"
+#include "integration/universal_file_input_stream_test.h"
+#include "integration/universal_file_output_stream_test.h"
+#include "integration/universal_stream_output_stream_test.h"
 /* TEST_ENVIRONMENT */
 #include "utf8stringbuf/utf8string.h"
 #include "u8/u8_trace.h"
@@ -86,8 +89,8 @@ int main (int argc, char *argv[]) {
         fprintf( stdout, "    + License: %s\n", META_INFO_LICENSE_STR );
     }
 
-    bool do_unit_tests = false;
-    bool do_integration_tests = false;
+    test_category_t mask = 0;
+    test_category_t pattern = -1;
 
     /* handle options */
     if ( argc == 2 )
@@ -97,34 +100,55 @@ int main (int argc, char *argv[]) {
             fprintf( stdout, "\nUsage:\n" );
             fprintf( stdout, "    %s -h for help\n", argv[0] );
             /* G_ENABLE_DIAGNOSTIC=1 prints more information on misusing the gtk libraries */
-            fprintf( stdout, "    G_ENABLE_DIAGNOSTIC=1 %s -u to run the unit-tests\n", argv[0] );
-            fprintf( stdout, "        (test functions of single software units\n" );
-            fprintf( stdout, "    G_ENABLE_DIAGNOSTIC=1 %s -i to run the integration tests\n", argv[0] );
-            fprintf( stdout, "        (test interactions between several software parts\n" );
-            fprintf( stdout, "    G_ENABLE_DIAGNOSTIC=1 %s -a to run all tests\n", argv[0] );
-        }
-        if ( utf8string_equals_str( argv[1], "-u" ) )
-        {
-            do_unit_tests = true;
-        }
-        if ( utf8string_equals_str( argv[1], "-i" ) )
-        {
-            do_integration_tests = true;
+            fprintf( stdout, "    G_ENABLE_DIAGNOSTIC=1 %s -a to run all continuous tests\n", argv[0] );
+            fprintf( stdout, "    G_ENABLE_DIAGNOSTIC=1 %s -R to run all continuous and release tests\n", argv[0] );
+            fprintf( stdout, "    G_ENABLE_DIAGNOSTIC=1 %s -@ to run only non-regular quest tests\n", argv[0] );
+
+            fprintf( stdout, "    G_ENABLE_DIAGNOSTIC=1 %s -U to run regular unit tests\n", argv[0] );
+            fprintf( stdout, "    G_ENABLE_DIAGNOSTIC=1 %s -I to run regular unit and integration tests\n", argv[0] );
+            fprintf( stdout, "    G_ENABLE_DIAGNOSTIC=1 %s -Q to run regular qualification tests\n", argv[0] );
+            fprintf( stdout, "    G_ENABLE_DIAGNOSTIC=1 %s -C to run regular coverage tests\n", argv[0] );
         }
         if ( utf8string_equals_str( argv[1], "-a" ) )
         {
-            do_unit_tests = true;
-            do_integration_tests = true;
+            mask = TEST_CATEGORY_CONTINUOUS | TEST_CATEGORY_QUEST;
+            pattern = TEST_CATEGORY_CONTINUOUS;
+        }
+        if ( utf8string_equals_str( argv[1], "-R" ) )
+        {
+            mask = TEST_CATEGORY_QUEST;
+            pattern = 0x0;
+        }
+        if ( utf8string_equals_str( argv[1], "-@" ) )
+        {
+            mask = TEST_CATEGORY_QUEST;
+            pattern = TEST_CATEGORY_QUEST;
+        }
+        if ( utf8string_equals_str( argv[1], "-U" ) )
+        {
+            mask = TEST_CATEGORY_UNIT | TEST_CATEGORY_QUEST;
+            pattern = TEST_CATEGORY_UNIT;
+        }
+        if ( utf8string_equals_str( argv[1], "-I" ) )
+        {
+            mask = TEST_CATEGORY_QUALIFICATION | TEST_CATEGORY_QUEST;
+            pattern = 0x0;
+        }
+        if ( utf8string_equals_str( argv[1], "-Q" ) )
+        {
+            mask = TEST_CATEGORY_QUALIFICATION | TEST_CATEGORY_QUEST;
+            pattern = TEST_CATEGORY_QUALIFICATION;
+        }
+        if ( utf8string_equals_str( argv[1], "-C" ) )
+        {
+            mask = TEST_CATEGORY_COVERAGE | TEST_CATEGORY_QUEST;
+            pattern = TEST_CATEGORY_COVERAGE;
         }
     }
 
     /* initialize the base libraries: gobject, gio, glib, gdk and gtk */
     {
-#if ( GTK_MAJOR_VERSION >= 4 )
         const gboolean success = gtk_init_check();
-#else
-        const gboolean success = gtk_init_check(&argc, &argv);
-#endif
         if ( ! success )
         {
             U8_LOG_WARNING("gtk could not be initialized.");
@@ -133,36 +157,15 @@ int main (int argc, char *argv[]) {
 
     /* start tests */
     test_runner_t runner;
-    test_runner_init ( &runner );
+    test_runner_init( &runner );
+    test_runner_set_filter( &runner, mask, pattern );
 
-    /* unit-tests test single software units and try to cover all control flows */
-    if ( do_unit_tests )
+    /* run all test cases, filtering is performed by the test runner (unless pattern contains masked bits) */
+    if ( ( pattern & ( ~ mask ) ) == 0x0 )
     {
-        /* data */
-        test_runner_run_suite( &runner, data_small_set_test_get_suite() );
-        test_runner_run_suite( &runner, data_rules_test_get_suite() );
-        test_runner_run_suite( &runner, data_uuid_test_get_suite() );
-        test_runner_run_suite( &runner, data_change_notifier_test_get_suite() );
-        test_runner_run_suite( &runner, data_database_listener_test_get_suite() );
-        test_runner_run_suite( &runner, data_database_head_test_get_suite() );
-        /* ctrl */
-        /* pencil */
-        test_runner_run_suite( &runner, geometry_rectangle_test_get_suite() );
-        test_runner_run_suite( &runner, geometry_connector_test_get_suite() );
-        test_runner_run_suite( &runner, geometry_non_linear_scale_test_get_suite() );
-        test_runner_run_suite( &runner, draw_classifier_contour_test_get_suite() );
-        test_runner_run_suite( &runner, draw_stereotype_image_test_get_suite() );
-        test_runner_run_suite( &runner, pencil_classifier_composer_test_get_suite() );
-        test_runner_run_suite( &runner, pencil_layout_data_test_get_suite() );
-        /* gui */
-        /* io */
-        test_runner_run_suite( &runner, io_txt_writer_test_get_suite() );
-        test_runner_run_suite( &runner, json_token_reader_test_get_suite() );
-        test_runner_run_suite( &runner, io_md_writer_test_get_suite() );
-        test_runner_run_suite( &runner, io_import_elements_test_get_suite() );
-        /* universal stream */
+        /* u8 */
         test_runner_run_suite( &runner, u8__test_get_suite() );
-        test_runner_run_suite( &runner, u8dir__test_get_suite() );
+        test_runner_run_suite( &runner, u8dir_file_test_get_suite() );
         test_runner_run_suite( &runner, universal_array_index_sorter_test_get_suite() );
         test_runner_run_suite( &runner, universal_array_list_test_get_suite() );
         test_runner_run_suite( &runner, universal_memory_output_stream_test_get_suite() );
@@ -172,7 +175,10 @@ int main (int argc, char *argv[]) {
         test_runner_run_suite( &runner, universal_buffer_output_stream_test_get_suite() );
         test_runner_run_suite( &runner, universal_memory_arena_test_get_suite() );
         test_runner_run_suite( &runner, universal_arena_list_test_get_suite() );
-        /* utf8stringbuf */
+        test_runner_run_suite( &runner, universal_file_input_stream_test_get_suite() );
+        test_runner_run_suite( &runner, universal_file_output_stream_test_get_suite() );
+        test_runner_run_suite( &runner, universal_stream_output_stream_test_get_suite() );
+        /* u8/utf8stringbuf */
         test_runner_run_suite( &runner, utf8codepoint_test_get_suite() );
         test_runner_run_suite( &runner, utf8codepointiterator_test_get_suite() );
         test_runner_run_suite( &runner, utf8stringbuf_test_get_suite() );
@@ -184,15 +190,18 @@ int main (int argc, char *argv[]) {
         test_runner_run_suite( &runner, utf8stringviewiterator_test_get_suite() );
         test_runner_run_suite( &runner, utf8stringviewtokenizer_test_get_suite() );
         test_runner_run_suite( &runner, utf8stream_writer_test_get_suite() );
-        test_runner_run_suite( &runner, gui_sketch_nav_tree_test_get_suite() );
-    }
 
-    /* integration tests test multiple software units and their interactions */
-    if ( do_integration_tests )
-    {
         /* data */
+        test_runner_run_suite( &runner, data_small_set_test_get_suite() );
+        test_runner_run_suite( &runner, data_rules_test_get_suite() );
+        test_runner_run_suite( &runner, data_uuid_test_get_suite() );
+        test_runner_run_suite( &runner, data_change_notifier_test_get_suite() );
+        test_runner_run_suite( &runner, data_database_listener_test_get_suite() );
+        test_runner_run_suite( &runner, data_database_head_test_get_suite() );
+
         test_runner_run_suite( &runner, data_database_reader_test_get_suite() );
         test_runner_run_suite( &runner, data_profile_part_test_get_suite() );
+
         /* ctrl */
         test_runner_run_suite( &runner, ctrl_multi_step_changer_test_get_suite() );
         test_runner_run_suite( &runner, ctrl_diagram_controller_test_get_suite() );
@@ -201,23 +210,39 @@ int main (int argc, char *argv[]) {
         test_runner_run_suite( &runner, ctrl_undo_redo_list_test_get_suite() );
         test_runner_run_suite( &runner, consistency_lifeline_test_get_suite() );
         test_runner_run_suite( &runner, consistency_drop_invisibles_test_get_suite() );
+
         /* pencil */
+        test_runner_run_suite( &runner, geometry_rectangle_test_get_suite() );
+        test_runner_run_suite( &runner, geometry_connector_test_get_suite() );
+        test_runner_run_suite( &runner, geometry_non_linear_scale_test_get_suite() );
+        test_runner_run_suite( &runner, draw_classifier_contour_test_get_suite() );
+        test_runner_run_suite( &runner, draw_stereotype_image_test_get_suite() );
+        test_runner_run_suite( &runner, pencil_classifier_composer_test_get_suite() );
+        test_runner_run_suite( &runner, pencil_layout_data_test_get_suite() );
+
         test_runner_run_suite( &runner, pencil_layouter_test_get_suite() );
         test_runner_run_suite( &runner, pencil_diagram_maker_test_get_suite() );
-        /* gui */
+
         /* io */
+        test_runner_run_suite( &runner, io_txt_writer_test_get_suite() );
+        test_runner_run_suite( &runner, json_token_reader_test_get_suite() );
+        test_runner_run_suite( &runner, io_md_writer_test_get_suite() );
+        test_runner_run_suite( &runner, io_import_elements_test_get_suite() );
+
         test_runner_run_suite( &runner, io_data_file_test_get_suite() );
         test_runner_run_suite( &runner, io_importer_test_get_suite() );
         test_runner_run_suite( &runner, io_export_model_traversal_test_get_suite() );
-        /* universal */
-        /* utf8stringbuf */
+
+        /* gui */
+        test_runner_run_suite( &runner, gui_sketch_nav_tree_test_get_suite() );
     }
 
     /* fetch failures */
     test_result_t res = test_get_result( &runner );
     fprintf( stdout,
-             "ALL TESTS - RESULT: total %d, failed: %d\n",
-             test_result_get_total( &res ),
+             "ALL TESTS - RESULT: skipped: %d, passed %d, failed: %d\n",
+             test_result_get_skipped( &res ),
+             test_result_get_passed( &res ),
              test_result_get_failed( &res )
            );
     exit_code = test_result_get_failed( &res );
