@@ -18,7 +18,12 @@ static test_case_result_t test_null_termination( test_fixture_t *fix );
 test_suite_t universal_memory_output_stream_test_get_suite(void)
 {
     test_suite_t result;
-    test_suite_init( &result, "universal_memory_output_stream_test_get_suite", &set_up, &tear_down );
+    test_suite_init( &result,
+                     "universal_memory_output_stream_test_get_suite",
+                     TEST_CATEGORY_UNIT | TEST_CATEGORY_CONTINUOUS | TEST_CATEGORY_COVERAGE,
+                     &set_up,
+                     &tear_down
+                   );
     test_suite_add_test_case( &result, "test_insert_regular", &test_insert_regular );
     test_suite_add_test_case( &result, "test_insert_border_cases", &test_insert_border_cases );
     test_suite_add_test_case( &result, "test_null_termination", &test_null_termination );
