@@ -17,7 +17,12 @@ static test_case_result_t test_write_and_flush( test_fixture_t *fix );
 test_suite_t utf8stream_writer_test_get_suite(void)
 {
     test_suite_t result;
-    test_suite_init( &result, "utf8stream_writer_test_get_suite", &set_up, &tear_down );
+    test_suite_init( &result,
+                     "utf8stream_writer_test_get_suite",
+                     TEST_CATEGORY_UNIT | TEST_CATEGORY_CONTINUOUS | TEST_CATEGORY_COVERAGE,
+                     &set_up,
+                     &tear_down
+                   );
     test_suite_add_test_case( &result, "test_write_and_flush", &test_write_and_flush );
     return result;
 }
